#include <Wire.h>
#include <SPI.h>
#include "Adafruit_PN532.h"

#define PN532_SS   (9)
// If using the breakout or shield with I2C, define just the pins connected
// to the IRQ and reset lines.  Use the values below (2, 3) for the shield!
#define PN532_IRQ   (2)
#define PN532_RESET (11)  // Not connected by default on the NFC Shield

Adafruit_PN532 nfc(PN532_SS);

//L298N
const  int ENA = 6 ;
const  int IN1 = 5 ;
const  int IN2 = 4 ;

#if defined(ARDUINO_ARCH_SAMD)
// for Zero, output on USB Serial console, remove line below if using programming port to program the Zero!
// also change #define in Adafruit_PN532.cpp library file
   #define Serial SerialUSB
#endif

void setup(void) {
    pinMode(ENA, OUTPUT);
    pinMode(IN1, OUTPUT);
    pinMode(IN2, OUTPUT); 
    
    Serial.begin(115200);
    SerialUSB.begin(115200);
    SerialUSB.println("Hello, Maduino Zero NFC! Makerfabs");

  nfc.begin();

  uint32_t versiondata = nfc.getFirmwareVersion();
  if (! versiondata) {
    SerialUSB.print("Didn't find PN53x board");
    while (1); // halt
  }
  
  // Got ok data, print it out!
  SerialUSB.print("Found chip PN5"); SerialUSB.println((versiondata>>24) & 0xFF, HEX); 
  SerialUSB.print("Firmware ver. "); SerialUSB.print((versiondata>>16) & 0xFF, DEC); 
  SerialUSB.print('.'); SerialUSB.println((versiondata>>8) & 0xFF, DEC);
  
  // Set the max number of retry attempts to read from a card
  // This prevents us from waiting forever for a card, which is
  // the default behaviour of the PN532.
  nfc.setPassiveActivationRetries(0xFF);
  
  // configure board to read RFID tags
  nfc.SAMConfig();
  
  SerialUSB.println("Waiting for an ISO14443A card");
}

void loop(void) {
  boolean result_success=0;
  uint8_t uid[] = { 0, 0, 0, 0, 0, 0, 0 };	// Buffer to store the returned UID
  uint8_t uidLength;				// Length of the UID (4 or 7 bytes depending on ISO14443A card type)
  
  // Wait for an ISO14443A type cards (Mifare, etc.).  When one is found
  // 'uid' will be populated with the UID, and uidLength will indicate
  // if the uid is 4 bytes (Mifare Classic) or 7 bytes (Mifare Ultralight)
  result_success = nfc.readPassiveTargetID(PN532_MIFARE_ISO14443A, &uid[0], &uidLength);
  
  if (result_success) {
    SerialUSB.println("Found a card!");
    SerialUSB.print("UID Length: ");SerialUSB.print(uidLength, DEC);SerialUSB.println(" bytes");
    SerialUSB.print("UID Value: ");
    for (uint8_t i=0; i < uidLength; i++) 
    {
      SerialUSB.print(" 0x");SerialUSB.print(uid[i], HEX); 
    }
    SerialUSB.println("");
    result_success=0;

    //analogWrite(ENA, 255);
    digitalWrite(ENA, HIGH);
    digitalWrite(IN1, LOW); //Switch direction
    digitalWrite(IN2, HIGH);
    delay(2000);
	// Wait 1 second before continuing
	delay(1000);
  }
  else
  {
    // PN532 probably timed out waiting for a card
    SerialUSB.println("Timed out waiting for a card");
  }
    digitalWrite(IN1, LOW); 
    digitalWrite(IN2, LOW);
}
